@@ -130,12 +130,7 @@ impl Rbatis {
     {
         let mut w = self.new_wrapper();
         let formats = T::formats(&self.driver_type().unwrap());
-        let mut wrapper_formats = HashMap::new();
-        for (k, v) in formats {
-            let r = v(k.as_str());
-            wrapper_formats.insert(k.clone(), r);
-        }
-        w = w.set_formats(wrapper_formats);
+        w = w.set_formats(formats);
         return w;
     }
 
